/* ########################################################### */
/* This Software is licensed under the GPL licensed Version 2, */
/* please read http://www.gnu.org/copyleft/gpl.html            */
/* ########################################################### */

#ifndef USAGE_H
#define USAGE_H

void
main_help(void);

void
columns_help(void);

void
lines_help(void);

void
tabulations_help(void);

void
direct_access_help(void);

void
tagging_help(void);

#endif
